@@ -30,9 +30,8 @@ class Disys_Calib:
 
     def __init__(self,path_to_data : str):
         """ Path to halcon tuples : tuples files are Col_Cog, Row_Cog, X_Tool, Y_Tool, Z_Tool, output will be saved in path_to_data path."""
-        self.SetLoggerHandlers()
         self.main_path = path_to_data
-        self.f = open('output.txt','w')
+        self.SetLoggerHandlers()
         try :         
             self.Col_Cog =       np.array(ha.read_tuple(self.main_path+R"\Col_Cog.tup"))
             self.Row_Cog =       np.array(ha.read_tuple(self.main_path+R"\Row_Cog.tup"))
@@ -41,7 +40,7 @@ class Disys_Calib:
             self.Z_Tool  =       np.array(ha.read_tuple(self.main_path+R"\Z_Tool.tup"))
         except:
             log.warning("Error : files not found. Input path may be not correct.", exc_info=True)
-            self.f("Error : files not found. Input path may be not correct.")
+            # self.f("Error : files not found. Input path may be not correct.")
             return 
         
         self.df = pd.DataFrame({'col_cog' :self.col_cog,'row_cog' : self.row_cog,
@@ -58,14 +57,13 @@ class Disys_Calib:
         print("Data features {}, labels features {}".format(X_feature_names.values,Y_feature_names.values))
         log.warning("Disys_Calib initialized : Amount of data {}.".format(n))
         log.warning("Data features {}, labels features {}".format(X_feature_names.values,Y_feature_names.values))
-        self.f.write("Disys_Calib initialized : Amount of data {}.".format(n))
-        self.f.write("Data features {}, labels features {}".format(X_feature_names.values,Y_feature_names.values))
+        # self.f.write("Disys_Calib initialized : Amount of data {}.".format(n))
+        # self.f.write("Data features {}, labels features {}".format(X_feature_names.values,Y_feature_names.values))
 
     def __init__(self,df_input : pd.DataFrame, mainpath, serialNum):
         """ Pandas dataframe with columns : Col_Cog, Row_Cog, X_Tool, Y_Tool, Z_Tool, optional mainpath to save output. """
+        self.main_path = mainpath
         self.SetLoggerHandlers()
-        self.main_path = []
-        self.f = open('output.txt','w')
         try :    
             self.df = pd.DataFrame({'col_cog' :df_input.Col_Cog,'row_cog' : df_input.Row_Cog,
                 'X' : df_input.X_Tool,'Y' : df_input.Y_Tool,'Z' :df_input.Z_Tool})
@@ -77,12 +75,10 @@ class Disys_Calib:
             self.X_Tool  =   self.df.X
             self.Y_Tool  =   self.df.Y
             self.Z_Tool  =   self.df.Z
-            self.main_path = mainpath
             self.serialNum = serialNum
-
         except:
             log.warning("Error : data not found. Check the names!", exc_info=True)
-            self.f.write("Error : data not found. Check the names!")
+            # self.f.write("Error : data not found. Check the names!")
             return 
         
         Data = self.df.values
@@ -96,8 +92,8 @@ class Disys_Calib:
         print("Data features {}, labels features {}".format(X_feature_names.values,Y_feature_names.values))
         log.warning("Disys_Calib initialized : Amount of data {}.".format(n))
         log.warning("Data features {}, labels features {}".format(X_feature_names.values,Y_feature_names.values))
-        self.f.write("Disys_Calib initialized : Amount of data {}.".format(n))
-        self.f.write("Data features {}, labels features {}".format(X_feature_names.values,Y_feature_names.values))
+        # self.f.write("Disys_Calib initialized : Amount of data {}.".format(n))
+        # self.f.write("Data features {}, labels features {}".format(X_feature_names.values,Y_feature_names.values))
 
     def CreateNN(self,width:int,height:int):
         """ Pandas dataframe with columns : Col_Cog, Row_Cog, X_Tool, Y_Tool, Z_Tool, optional mainpath to save output. """
@@ -127,9 +123,9 @@ class Disys_Calib:
         log.warning("Amount of data for training: {}".format(n_train))
         log.warning("Amount of data for test: {}".format(n_test))
         log.warning("\n********** Start training **********")
-        self.f.write("Amount of data for training: {}\n".format(n_train))
-        self.f.write("Amount of data for test: {}\n".format(n_test))
-        self.f.write("\n********** Start training **********\n")
+        # self.f.write("Amount of data for training: {}\n".format(n_train))
+        # self.f.write("Amount of data for test: {}\n".format(n_test))
+        # self.f.write("\n********** Start training **********\n")
         performance_best = 1e3
         net = prn.CreateNN([2,100,3])
         step = 5
@@ -141,13 +137,13 @@ class Disys_Calib:
             err = np.sqrt(np.power(delta[:,0],2)+np.power(delta[:,1],2)+np.power(delta[:,2],2))
             print("ERRORE RETE step {}/{}: Y_test ->  min {:.4f} , mean {:.4f} , max {:.4f} ".format((i+1),step,np.min(err),np.mean(err),np.max(err)) )
             log.warning("ERRORE RETE step {}/{}: Y_test ->  min {:.4f} , mean {:.4f} , max {:.4f} ".format((i+1),step,np.min(err),np.mean(err),np.max(err)) )
-            self.f.write("ERRORE RETE step {}/{}: Y_test ->  min {:.4f} , mean {:.4f} , max {:.4f} \n".format((i+1),step,np.min(err),np.mean(err),np.max(err)) )
+            # self.f.write("ERRORE RETE step {}/{}: Y_test ->  min {:.4f} , mean {:.4f} , max {:.4f} \n".format((i+1),step,np.min(err),np.mean(err),np.max(err)) )
             if (np.mean(err) < performance_best):
                 best_net = net
                 performance_best = np.mean(err)
         print("************************************")
         log.warning("************************************")
-        self.f.write("************************************\n")
+        # self.f.write("************************************\n")
         
 
         #OUTPUT
@@ -199,7 +195,7 @@ class Disys_Calib:
         self.err = np.sqrt(np.power(delta[:,0],2)+np.power(delta[:,1],2)+np.power(delta[:,2],2))
         print("\nERRORE RETE finale: min {:.5f} , mean {:.5f} , max {:.5f} ".format(np.min(err),np.mean(err),np.max(err)) )
         log.warning("\nERRORE RETE finale: min {:.5f} , mean {:.5f} , max {:.5f} ".format(np.min(err),np.mean(err),np.max(err)) )
-        self.f.write("\nERRORE RETE finale: min {:.5f} , mean {:.5f} , max {:.5f} \n".format(np.min(err),np.mean(err),np.max(err)) )
+        # self.f.write("\nERRORE RETE finale: min {:.5f} , mean {:.5f} , max {:.5f} \n".format(np.min(err),np.mean(err),np.max(err)) )
         with open(self.main_path+R"\dati calibrazione\Report_Rete.txt",'w') as ff:
             ff.write("---   Final network    ---\nmin error  {:.5f}mm,\nmean error {:.5f}mm,\nmax error  {:.5f}mm. "
                 .format(np.min(err),np.mean(err),np.max(err)) )
@@ -208,7 +204,7 @@ class Disys_Calib:
             self.plotErrorXZ(width,height).savefig(self.main_path+R"\dati calibrazione\ErrorPlotXZ.tif")
         except Exception as err:
             log.warning("Error ", exc_info=True)
-            self.f.write("Eccezione : %S\n",err)
+            # self.f.write("Eccezione : %S\n",err)
 
         return self.mlp,best_net
 
@@ -332,11 +328,11 @@ class Disys_Calib:
             selectedPointsDF.to_csv(self.main_path+R"\dati calibrazione\maxerrorpoints.csv", index=False, sep=' ')
         except Exception as err:
             log.warning("Error ", exc_info=True)
-            self.f.write("Eccezione : %S\n",err)
+            # self.f.write("Eccezione : %S\n",err)
 
     def SetLoggerHandlers(self):
         # self.consoleH = logging.StreamHandler()
-        self.fileH = logging.FileHandler('pyoutput.log', mode='w')
+        self.fileH = logging.FileHandler(self.main_path+"pyoutput.log", mode='w')
         # self.consoleH.setLevel(logging.WARNING)
         # self.fileH.setLevel(logging.INFO)
         # log.addHandler(self.consoleH)
